@@ -203,8 +203,9 @@ class SentrySettings(BaseSettings):
     """Configures sentry for the application."""
 
     class Config:
-        env_prefix = "SENTRY_"
         case_sensitive = True
+        env_file = ".env"
+        env_prefix = "SENTRY_"
 
     DSN: str = ""
     """The sentry DSN. Set as empty string to disable sentry reporting."""
@@ -212,6 +213,22 @@ class SentrySettings(BaseSettings):
     """% of requests traced by sentry, `0.0` means none, `1.0` means all."""
 
 
+class ServerSettings(BaseSettings):
+    """Server configurations."""
+
+    class Config:
+        case_sensitive = True
+        env_file = ".env"
+        env_prefix = "SERVER_"
+
+    APP_LOC: str = "app.main:app"
+    HOST: str = "localhost"
+    KEEPALIVE: int = 65
+    PORT: int = 8000
+    RELOAD: bool = False
+    RELOAD_DIRS: list[str] = ["src/"]
+
+
 # `.parse_obj()` thing is a workaround for pyright and pydantic interplay, see:
 # https://github.com/pydantic/pydantic/issues/3753#issuecomment-1087417884
 api = APISettings.parse_obj({})
@@ -228,3 +245,5 @@ redis = RedisSettings.parse_obj({})
 """Redis settings."""
 sentry = SentrySettings.parse_obj({})
 """Sentry settings."""
+server = ServerSettings.parse_obj({})
+"""Server settings."""
